@@ -1,7 +1,7 @@
 from pathlib import Path
 
 from poetry.core.poetry import Poetry
-from poetry_multiproject_plugin.overrides import factory_override
+from poetry.factory import Factory
 from poetry_multiproject_plugin.repo import repo
 
 
@@ -9,8 +9,7 @@ def create_modified_poetry(poetry: Poetry, toml: str) -> Poetry:
     cwd = Path.cwd()
     path = Path(toml).absolute()
 
-    factory = factory_override.MultiProjectFactory(path.name)
-    modified = factory.create_poetry(path.parent)
+    modified = Factory().create_poetry(path.parent)
 
     modified.file.parent = repo.find_workspace_root(cwd) or modified.file.parent
 
